pilas.camara

Home | Trees | Indices | Help |
--- | --- | --- | --- | ---

Package pilas :: Module camara |
[hide private]
[frames] | no frames]

# Module camara

source code

Classes | [hide private]
| Camara Representa el punto de vista de la ventana.

Variables | [hide private]
| __package__ = ``'``pilas``'``

Home | Trees | Indices | Help |
--- | --- | --- | --- | ---

Generated by Epydoc 3.0.1 on Sun Jan 27 23:57:19 2013 | http://epydoc.sourceforge.net